@@ -125,7 +125,8 @@ def run():
         if dst_space_id:
             print(f"destination space_id is: {dst_space_id}")
         else:
-            raise ValueError(f"the destination space id/name {args.dst_space_id_name} you specified does not exist")
+            raise ValueError(f"the destination space id/name {args.dst_space_id_name} you specified does not exist "
+                             f"or you may not have permission to access it")
 
     space_id = None
     if args.space_id_name:
@@ -133,7 +134,8 @@ def run():
         if space_id:
             print(f"octopus space_id is: {space_id}")
         elif args.action not in Actions.clone_space_actions:
-            raise ValueError(f"the space id/name {args.space_id_name} you specified does not exist")
+            raise ValueError(f"the space id/name {args.space_id_name} you specified does not exist "
+                             f"or you may not have permission to access it")
         elif input(f"Are you sure you want to {args.action} from nonexistent space {args.space_id_name} [Y/n]?") == 'Y':
             space_id = args.space_id_name
         else:
